@@ -13,7 +13,7 @@ from gradient.cli.common import api_key_option, del_if_value_is_none, ClickGroup
 from gradient.cli_constants import CLI_PS_CLIENT_NAME
 from gradient.commands import deployments as deployments_commands
 from gradient.commands.deployments import DeploymentRemoveTagsCommand, DeploymentAddTagsCommand, \
-    GetDeploymentMetricsCommand, StreamDeploymentMetricsCommand, DeploymentLogsCommand
+    GetDeploymentMetricsCommand, ListDeploymentMetricsCommand, StreamDeploymentMetricsCommand, DeploymentLogsCommand
 
 
 def get_workspace_handler(api_key):
@@ -703,9 +703,9 @@ def deployment_remove_tags(id, options_file, api_key, **kwargs):
     "--metric",
     "metrics_list",
     multiple=True,
-    type=ChoiceType(constants.METRICS_MAP, case_sensitive=False),
+    type=str,
     default=(constants.BuiltinMetrics.cpu_percentage, constants.BuiltinMetrics.memory_usage),
-    help="One or more metrics that you want to read. Defaults to cpuPercentage and memoryUsage",
+    help=("One or more metrics that you want to read: {}. Defaults to cpuPercentage and memoryUsage. To view available custom metrics, use command: `gradient deployments metrics list`".format(', '.join(map(str, constants.METRICS_MAP)))),
     cls=common.GradientOption,
 )
 @click.option(
@@ -735,6 +735,45 @@ def get_deployment_metrics(deployment_id, metrics_list, interval, start, end, op
     command = GetDeploymentMetricsCommand(api_key=api_key)
     command.execute(deployment_id, start, end, interval, built_in_metrics=metrics_list)
 
+@deployments_metrics.command(
+    "list",
+    short_help="List model deployment metrics",
+    help="List model deployment metrics. Shows CPU and RAM usage by default",
+)
+@click.option(
+    "--id",
+    "deployment_id",
+    required=True,
+    cls=common.GradientOption,
+    help="ID of the model deployment",
+)
+@click.option(
+    "--interval",
+    "interval",
+    default="30s",
+    help="Interval",
+    cls=common.GradientOption,
+)
+@click.option(
+    "--start",
+    "start",
+    type=click.DateTime(),
+    help="Timestamp of first time series metric to collect",
+    cls=common.GradientOption,
+)
+@click.option(
+    "--end",
+    "end",
+    type=click.DateTime(),
+    help="Timestamp of last time series metric to collect",
+    cls=common.GradientOption,
+)
+@api_key_option
+@common.options_file
+def list_deployment_metrics(deployment_id, interval, start, end, options_file, api_key):
+    command = ListDeploymentMetricsCommand(api_key=api_key)
+    command.execute(deployment_id, start, end, interval)
+
 
 @deployments_metrics.command(
     "stream",
